.. :changelog:

History
-------

Pending Release
---------------

.. Insert new release notes below this line

2.0.0 (2019-02-28)
------------------

* Drop Python 2 support, only Python 3.4+ is supported now.

1.0.0 (2016-04-22)
------------------

* First release on PyPI
